@@ -110,6 +110,15 @@ ROOT_URLCONF = 'djangopypi2.website.urls'
 # Python dotted path to the WSGI application used by Django's runserver.
 WSGI_APPLICATION = 'djangopypi2.website.wsgi.application'
 
+LOGIN_URL = '/users/login/'
+LOGOUT_URL = '/users/logout/'
+LOGIN_REDIRECT_URL = '/'
+
+TEMPLATE_CONTEXT_PROCESSORS = [
+    'django.contrib.auth.context_processors.auth',
+    'django.core.context_processors.request',
+]
+
 INSTALLED_APPS = (
     'django.contrib.auth',
     'django.contrib.contenttypes',
@@ -119,7 +128,9 @@ INSTALLED_APPS = (
     'django.contrib.staticfiles',
     'django.contrib.admin',
     'djangopypi2.apps.pypi_ui',
-    'djangopypi2.apps.pypi_config',
+    'djangopypi2.apps.pypi_users',
+    'djangopypi2.apps.pypi_metadata',
+    'djangopypi2.apps.pypi_packages',
     'djangopypi2.apps.pypi_frontend',
 )
 
